@@ -1,7 +1,8 @@
 from django.conf.urls import url
 from django.contrib.auth.decorators import login_required
 
-from .views import SignupView, LoginView, LogoutView, EmailView, PasswordResetView, PasswordResetFromKeyView
+from .views import SignupView, LoginView, LogoutView, EmailView, PasswordResetView, PasswordResetFromKeyView, \
+                   PasswordChangeView, PasswordSetView
 
 
 allauth_api_urlpatterns = [
@@ -15,6 +16,12 @@ allauth_api_urlpatterns = [
 
     # Password
     url(r"^api/v1/auth/password/reset/$", PasswordResetView.as_view(), name="rest_password_reset"),
-    url(r"^api/v1/auth/password/reset/key/(?P<uidb36>[0-9A-Za-z]+)/(?P<key>.+)/$", PasswordResetFromKeyView.as_view(),
+    url(r"^api/v1/auth/password/reset/key/$", PasswordResetFromKeyView.as_view(),
         name="rest_reset_password_from_key"),
+
+    url(r"^api/v1/auth/password/change/$", PasswordChangeView.as_view(),
+        name="rest_password_change"),
+
+    url(r"^api/v1/auth/password/set/$", PasswordSetView.as_view(),
+        name="rest_password_set"),
 ]
