@@ -10,7 +10,7 @@ _urlpatterns = [
     url(r'^$', UserApiViewSet.as_view({'get': 'list', 'post': 'create'}), name='rest-list'),
 
     url(r'^(?P<sso_id>[-_\w]+)/$',
-        UserApiViewSet.as_view({'get': 'retrieve', 'patch': 'partial_update', 'delete': 'delete_test_user'},
+        UserApiViewSet.as_view({'get': 'retrieve', 'patch': 'partial_update'},
                                name='rest-detail'),
         name='rest-detail'),
 ]
