@@ -9,8 +9,6 @@ from ...apps.users.utils import fetch_remote_user, create_local_user_from_remote
                               create_local_user_from_apigateway_headers
 
 from ...apps.profiles.models import Profile
-from ...apps.groups.utils import set_default_user_groups, set_default_profile_groups
-from ...apps.api_gateway.functions import get_apigateway_profile_groups_from_header
 from ... import app_settings
 
 
