@@ -1,8 +1,6 @@
 import logging
 
 from django.core.exceptions import ImproperlyConfigured
-from django.conf import settings
-from django.urls import reverse
 from django.utils.encoding import smart_str
 
 from jwt.exceptions import InvalidSignatureError
@@ -130,18 +128,30 @@ class DjangoSsoAppAuthenticationMiddleware(DjangoSsoAppAuthenticationBackendMidd
         request_jwt_sso_id = decoded_jwt[SSO_ID_JWT_KEY]
 
         if apigateway_enabled:
-            consumer_custom_id = request.META.get(self.header, None)
-            consumer_is_anonymous = request.META.get(self.anonymous_header, None)
+            consumer_custom_id = request.META.get(self.consumer_id_header, None)
+            consumer_is_anonymous_header = request.META.get(self.anonymous_consumer_header, None)
 
-            if consumer_is_anonymous or not consumer_custom_id:
+            if consumer_is_anonymous_header is not None and \
+                    consumer_is_anonymous_header == self.anonymous_consumer_header_value:
+                consumer_is_anonymous = True
+            else:
+                if consumer_custom_id is None:
+                    consumer_is_anonymous = True
+                else:
+                    if consumer_custom_id in self.anonymous_consumer_custom_ids:
+                        consumer_is_anonymous = True
+                    else:
+                        consumer_is_anonymous = False
+
+            if consumer_is_anonymous:
                 # If anonymous consumer header specified or consumer custom id header don't exist
+                # or consumer custom_id is one of anonymous consumer custom_ids
                 # then remove any existing authenticated user and return (leaving request.user set to
                 # AnonymousUser by the AuthenticationMiddleware).
 
                 logger.info('User is anonymous')
 
                 self._remove_invalid_user(request)
-                self._clear_response_jwt()
 
                 return
 
@@ -183,8 +193,9 @@ class DjangoSsoAppAuthenticationMiddleware(DjangoSsoAppAuthenticationBackendMidd
                 set_session_key(request, '__dssoa__redirect', e.response)
 
         except ServiceSubscriptionRequiredException as e:
-            logger.info('User must subscribe service')
-            set_session_key(request, '__dssoa__redirect', e.response)
+            if self._request_path_is_disabled_for_users_to_subscribe(request):
+                logger.info('User must subscribe service')
+                set_session_key(request, '__dssoa__redirect', e.response)
 
         except Exception as e:
             logger.exception('Generic middleware backend exception "{}"'.format(e))
