@@ -37,15 +37,6 @@ DJANGO_SSO_APP_SHAPE = env('DJANGO_SSO_APP_SHAPE', default='backend_only')
 
 DJANGO_SSO_APP_BASE_DJANGO_APPS = [
     'django_sso_app',
-
-    'django_sso_app.core.apps.status',
-    'django_sso_app.core.apps.profiles',
-    'django_sso_app.core.apps.groups',
-    'django_sso_app.core.apps.devices',
-    'django_sso_app.core.apps.services',
-    'django_sso_app.core.apps.api_gateway',
-    'django_sso_app.core.apps.passepartout',
-    'django_sso_app.core.apps.events'
 ]
 
 DJANGO_SSO_APP_DJANGO_APPS = [
